create_device_user_code

Function create_device_user_code 

pub async fn create_device_user_code(
    configuration: &Configuration,
) -> Result<(), Error<CreateDeviceUserCodeError>>
Retrieve a user_code that is part of an in-progress Device Authorization Grant. This API is useful if you want to build your own login workflow to complete a device grant. OR Retrieve a user_code that is part of an in-progress Device Authorization Grant. This API is useful if you want to build your own login workflow to complete a device grant. This request will require an API key.