pub async fn register(
configuration: &Configuration,
x_fusion_auth_tenant_id: Option<&str>,
registration_request: Option<RegistrationRequest>,
) -> Result<RegistrationResponse, Error<RegisterError>>Expand description
Registers a user for an application. If you provide the User and the UserRegistration object on this request, it will create the user as well as register them for the application. This is called a Full Registration. However, if you only provide the UserRegistration object, then the user must already exist and they will be registered for the application. The user Id can also be provided and it will either be used to look up an existing user or it will be used for the newly created User.