pub async fn retrieve_device_validate(
configuration: &Configuration,
user_code: Option<&str>,
client_id: Option<&str>,
) -> Result<(), Error<RetrieveDeviceValidateError>>Expand description
Validates the end-user provided user_code from the user-interaction of the Device Authorization Grant. If you build your own activation form you should validate the user provided code prior to beginning the Authorization grant. OR Validates the end-user provided user_code from the user-interaction of the Device Authorization Grant. If you build your own activation form you should validate the user provided code prior to beginning the Authorization grant.