pub enum ExistingUserStrategy {
MustExist,
MustNotExist,
}Expand description
ExistingUserStrategy : Represent the various statesexpectations of a user in the context of starting verification Represent the various statesexpectations of a user in the context of starting verification
Variants