pub struct LoginPreventedResponse {
pub action_id: Option<Uuid>,
pub actioner_user_id: Option<Uuid>,
pub expiry: Option<i64>,
pub localized_name: Option<String>,
pub localized_option: Option<String>,
pub localized_reason: Option<String>,
pub name: Option<String>,
pub option: Option<String>,
pub reason: Option<String>,
pub reason_code: Option<String>,
}Expand description
LoginPreventedResponse : The summary of the action that is preventing login to be returned on the login response.
Fields
action_id: Option<Uuid>actioner_user_id: Option<Uuid>expiry: Option<i64>The number of milliseconds since the unix epoch: January 1, 1970 00:00:00 UTC. This value is always in UTC.
localized_name: Option<String>localized_option: Option<String>localized_reason: Option<String>name: Option<String>option: Option<String>reason: Option<String>reason_code: Option<String>Implementations
Sourceimpl LoginPreventedResponse
impl LoginPreventedResponse
Sourcepub fn new() -> LoginPreventedResponse
pub fn new() -> LoginPreventedResponse
The summary of the action that is preventing login to be returned on the login response.