pub struct RetrieveUserCodeUsingApiKeyRequest {
pub tenant_id: Option<Uuid>,
pub user_code: Option<String>,
}Expand description
RetrieveUserCodeUsingApiKeyRequest : The request object for retrieving a user code that is part of an in-progress Device Authorization Grant using an API key
Fields
tenant_id: Option<Uuid>user_code: Option<String>Implementations
Sourceimpl RetrieveUserCodeUsingApiKeyRequest
impl RetrieveUserCodeUsingApiKeyRequest
Sourcepub fn new() -> RetrieveUserCodeUsingApiKeyRequest
pub fn new() -> RetrieveUserCodeUsingApiKeyRequest
The request object for retrieving a user code that is part of an in-progress Device Authorization Grant using an API key